@@ -4,6 +4,7 @@ Tokenizer generic functions
 """
 import re
 from typing import Iterable, List, Union
+import warnings
 
 from pythainlp.tokenize import (
     DEFAULT_SENT_TOKENIZE_ENGINE,
@@ -29,16 +30,16 @@ def clause_tokenize(doc: List[str]) -> List[List[str]]:
 
     :Example:
 
+    Clause tokenizer::
+
         from pythainlp.tokenize import clause_tokenize
 
         clause_tokenize(["ฉัน","นอน","และ","คุณ","เล่น","มือถือ","ส่วน","น้อง","เขียน","โปรแกรม"])
-        [['ฉัน', 'นอน'],
-        ['และ', 'คุณ', 'เล่น', 'มือถือ'],
-        ['ส่วน', 'น้อง', 'เขียน', 'โปรแกรม']]
-    """
-    if not doc or not isinstance(doc, str):
-        return []
+        # [['ฉัน', 'นอน'],
+        # ['และ', 'คุณ', 'เล่น', 'มือถือ'],
+        # ['ส่วน', 'น้อง', 'เขียน', 'โปรแกรม']]
 
+    """
     from pythainlp.tokenize.crfcls import segment
 
     return segment(doc)
@@ -68,6 +69,7 @@ def word_tokenize(
           Thai Character Cluster
         * *newmm-safe* - newmm, with a mechanism to help avoid long
           processing time for text with continuous ambiguous breaking points
+        * *nlpo3* - Python binding for nlpO3. It is newmm engine in Rust.
         * *longest* - dictionary-based, Longest Matching
         * *icu* - wrapper for ICU (International Components for Unicode,
           using PyICU), dictionary-based
@@ -80,6 +82,12 @@ def word_tokenize(
         * *nercut* - Dictionary-based maximal matching word segmentation,
           constrained with Thai Character Cluster (TCC) boundaries,
           and combining tokens that are parts of the same named-entity.
+        * *sefr_cut* - wrapper for
+          `SEFR CUT <https://github.com/mrpeerat/SEFR_CUT>`_.,
+        * *tltk* - wrapper for
+          `TLTK <https://pypi.org/project/tltk/>`_.,
+        * *oskut* - wrapper for
+          `OSKut <https://github.com/mrpeerat/OSKut>`_.,
 
     :Note:
         - The parameter **custom_dict** can be provided as an argument \
@@ -173,6 +181,31 @@ def word_tokenize(
         from pythainlp.tokenize.nercut import segment
 
         segments = segment(text)
+    elif engine == "sefr_cut":
+        from pythainlp.tokenize.sefr_cut import segment
+
+        segments = segment(text)
+    elif engine == "tltk":
+        from pythainlp.tokenize.tltk import segment
+
+        segments = segment(text)
+    elif engine == "oskut":
+        from pythainlp.tokenize.oskut import segment
+
+        segments = segment(text)
+    elif engine == "nlpo3":
+        from pythainlp.tokenize.nlpo3 import segment
+        if isinstance(custom_dict, str):
+            segments = segment(text, custom_dict=custom_dict)
+        elif not isinstance(custom_dict, str) and custom_dict is not None:
+            raise ValueError(
+                f"""Tokenizer \"{engine}\":
+                custom_dict must be a str.
+                It is a dictionary name as assigned with load_dict().
+                See pythainlp.tokenize.nlpo3.load_dict()"""
+            )
+        else:
+            segments = segment(text)
     else:
         raise ValueError(
             f"""Tokenizer \"{engine}\" not found.
@@ -205,6 +238,7 @@ def sent_tokenize(
         * *whitespace+newline* - split by whitespaces and newline.
         * *whitespace* - split by whitespaces. Specifiaclly, with \
                          :class:`regex` pattern  ``r" +"``
+        * *tltk* - split by `TLTK <https://pypi.org/project/tltk/>`_.,
     :Example:
 
     Split the text based on *whitespace*::
@@ -261,6 +295,10 @@ def sent_tokenize(
         segments = re.split(r" +", text, re.U)
     elif engine == "whitespace+newline":
         segments = text.split()
+    elif engine == "tltk":
+        from pythainlp.tokenize.tltk import sent_tokenize as segment
+
+        segments = segment(text)
     else:
         raise ValueError(
             f"""Tokenizer \"{engine}\" not found.
@@ -302,6 +340,9 @@ def subword_tokenize(
         * *tcc* (default) -  Thai Character Cluster (Theeramunkong et al. 2000)
         * *etcc* - Enhanced Thai Character Cluster (Inrut et al. 2001)
         * *wangchanberta* - SentencePiece from wangchanberta model.
+        * *dict* - newmm word tokenizer with a syllable dictionary
+        * *ssg* - CRF syllable segmenter for Thai
+        * *tltk* - syllable tokenizer from tltk
 
     :Example:
 
@@ -346,19 +387,34 @@ def subword_tokenize(
     if not text or not isinstance(text, str):
         return []
 
+    segments = []
+
     if engine == "tcc":
         from pythainlp.tokenize.tcc import segment
     elif engine == "etcc":
         from pythainlp.tokenize.etcc import segment
     elif engine == "wangchanberta":
         from pythainlp.wangchanberta import segment
+    elif engine == "dict":  # use syllable dictionary
+        words = word_tokenize(text)
+        for word in words:
+            segments.extend(
+                word_tokenize(
+                    text=word, custom_dict=DEFAULT_SYLLABLE_DICT_TRIE
+                )
+            )
+    elif engine == "ssg":
+        from pythainlp.tokenize.ssg import segment
+    elif engine == "tltk":
+        from pythainlp.tokenize.tltk import syllable_tokenize as segment
     else:
         raise ValueError(
             f"""Tokenizer \"{engine}\" not found.
             It might be a typo; if not, please consult our document."""
         )
 
-    segments = segment(text)
+    if segments == []:
+        segments = segment(text)
 
     if not keep_whitespace:
         segments = [token.strip(" ") for token in segments if token.strip(" ")]
@@ -374,6 +430,8 @@ def syllable_tokenize(
     """
     Syllable tokenizer.
 
+    **syllable_tokenize is deprecated, use subword_tokenize instead**
+
     Tokenizes text into syllable (Thai: พยางค์), a unit of
     pronunciation having one vowel sound.  For example, the word 'รถไฟ'
     contains two syallbles including 'รถ', and 'ไฟ'.
@@ -403,6 +461,11 @@ def syllable_tokenize(
         ['รถ', 'ไฟ', 'สมัย', 'ใหม่', 'ใช้', 'กำ', 'ลัง', 'จาก', 'หัว',
         'รถ', 'จักร', 'ดี', 'เซล', ' ', 'หรือ', 'จาก', 'ไฟ', 'ฟ้า']
     """
+    warnings.warn(
+        """syllable_tokenize will be deprecated in PyThaiNLP version 3.1,
+        use subword_tokenize instead""",
+        PendingDeprecationWarning
+    )
 
     if not text or not isinstance(text, str):
         return []
